@@ -20,10 +20,6 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id$ *)
-
-open Gobject
-
 (** Action-based menus and toolbars *)
 
 (** {3 GtkAction} *)
@@ -31,33 +27,21 @@ open Gobject
 (** @since GTK 2.4
     @gtkdoc gtk GtkAction *)
 class action_signals :
-  ([> Gtk.action ] as 'b) obj ->
+  ([> Gtk.action ] as 'b) Gobject.obj ->
   object ('a)
-    val obj : 'b obj
+    val obj : 'b Gobject.obj
     val after : bool
     method after : < after : 'a; .. > as 'a
     method activate : callback:(unit -> unit) -> GtkSignal.id
-    method notify_hide_if_empty : callback:(bool -> unit) -> GtkSignal.id
-    method notify_icon_name : callback:(string -> unit) -> GtkSignal.id
-    method notify_is_important : callback:(bool -> unit) -> GtkSignal.id
-    method notify_label : callback:(string -> unit) -> GtkSignal.id
-    method notify_name : callback:(string -> unit) -> GtkSignal.id
-    method notify_sensitive : callback:(bool -> unit) -> GtkSignal.id
-    method notify_short_label : callback:(string -> unit) -> GtkSignal.id
-    method notify_stock_id : callback:(GtkStock.id -> unit) -> GtkSignal.id
-    method notify_tooltip : callback:(string -> unit) -> GtkSignal.id
-    method notify_visible : callback:(bool -> unit) -> GtkSignal.id
-    method notify_visible_horizontal : callback:(bool -> unit) -> GtkSignal.id
-    method notify_visible_vertical : callback:(bool -> unit) -> GtkSignal.id
   end
 
 (** @since GTK 2.4
     @gtkdoc gtk GtkAction *)
 class action_skel :
-  ([> Gtk.action ] as 'a) obj ->
+  ([> Gtk.action ] as 'a) Gobject.obj ->
   object
-    val obj : 'a obj
-    method as_action : Gtk.action obj
+    val obj : 'a Gobject.obj
+    method as_action : Gtk.action Gobject.obj
 
     (** Properties *)
 
@@ -104,10 +88,10 @@ class action_skel :
 (** @since GTK 2.4
     @gtkdoc gtk GtkAction *)
 class action :
-  ([> Gtk.action ] as 'a) obj ->
+  ([> Gtk.action ] as 'a) Gobject.obj ->
   object
     inherit action_skel
-    val obj : 'a obj
+    val obj : 'a Gobject.obj
     method connect : action_signals
   end
 
@@ -119,21 +103,20 @@ val action : name:string -> unit -> action
 (** @since GTK 2.4
     @gtkdoc gtk GtkToggleAction *)
 class toggle_action_signals :
-  ([> Gtk.toggle_action ] as 'b) obj ->
+  ([> Gtk.toggle_action ] as 'b) Gobject.obj ->
   object
     inherit action_signals
-    val obj : 'b obj
+    val obj : 'b Gobject.obj
     method toggled : callback:(unit -> unit) -> GtkSignal.id
-    method notify_draw_as_radio : callback:(bool -> unit) -> GtkSignal.id
   end
 
 (** @since GTK 2.4
     @gtkdoc gtk GtkToggleAction *)
 class toggle_action_skel :
-  ([> Gtk.toggle_action ] as 'a) obj ->
+  ([> Gtk.toggle_action ] as 'a) Gobject.obj ->
   object
     inherit action_skel
-    val obj : 'a obj
+    val obj : 'a Gobject.obj
     method draw_as_radio : bool
     method get_active : bool
     method set_active : bool -> unit
@@ -144,10 +127,9 @@ class toggle_action_skel :
 (** @since GTK 2.4
     @gtkdoc gtk GtkToggleAction *)
 class toggle_action :
-  ([> Gtk.toggle_action ] as 'a) obj ->
+  ([> Gtk.toggle_action ] as 'a) Gobject.obj ->
   object
     inherit toggle_action_skel
-    val obj : 'a obj
     method connect : toggle_action_signals
   end
 
@@ -158,10 +140,10 @@ val toggle_action : name:string -> unit -> toggle_action
 (** @since GTK 2.4
     @gtkdoc gtk GtkRadioAction *)
 class radio_action_signals :
-  ([> Gtk.radio_action] as 'b) obj ->
+  ([> Gtk.radio_action] as 'b) Gobject.obj ->
   object
     inherit toggle_action_signals
-    val obj : 'b obj
+    val obj : 'b Gobject.obj
     method changed :
       callback:(int -> unit) -> GtkSignal.id
   end
@@ -169,12 +151,12 @@ class radio_action_signals :
 (** @since GTK 2.4
     @gtkdoc gtk GtkRadioAction *)
 class radio_action :
-  ([> Gtk.radio_action] as 'a) obj ->
+  ([> Gtk.radio_action] as 'a) Gobject.obj ->
   object
     inherit toggle_action_skel
-    val obj : 'a obj
+    val obj : 'a Gobject.obj
     method connect : radio_action_signals
-    method as_radio_action : Gtk.radio_action obj
+    method as_radio_action : Gtk.radio_action Gobject.obj
     method get_current_value : int
     method set_group : Gtk.radio_action Gtk.group -> unit
     method set_value : int -> unit
@@ -190,10 +172,10 @@ val radio_action : ?group:radio_action -> name:string -> value:int -> unit -> ra
 (** @since GTK 2.4
     @gtkdoc gtk GtkActionGroup *)
 class action_group_signals :
-  ([> Gtk.action_group ] as 'b) obj ->
+  ([> Gtk.action_group ] as 'b) Gobject.obj ->
   object ('a)
     val after : bool
-    val obj : 'b obj
+    val obj : 'b Gobject.obj
     method after : 'a
     method connect_proxy : callback:(action -> GObj.widget -> unit) -> GtkSignal.id
     method disconnect_proxy : callback:(action -> GObj.widget -> unit) -> GtkSignal.id
@@ -204,10 +186,10 @@ class action_group_signals :
 (** @since GTK 2.4
     @gtkdoc gtk GtkActionGroup *)
 class action_group :
-  ([> Gtk.action_group ] as 'a) obj ->
+  ([> Gtk.action_group ] as 'a) Gobject.obj ->
   object
-    val obj : 'a obj
-    method as_group : Gtk.action_group obj
+    val obj : 'a Gobject.obj
+    method as_group : Gtk.action_group Gobject.obj
     method connect : action_group_signals
     method sensitive : bool
     method set_sensitive : bool -> unit
@@ -279,8 +261,6 @@ class ui_manager_signals :
     method disconnect_proxy : callback:(action -> GObj.widget -> unit) -> GtkSignal.id
     method post_activate : callback:(action -> unit) -> GtkSignal.id
     method pre_activate : callback:(action -> unit) -> GtkSignal.id
-    method notify_add_tearoffs : callback:(bool -> unit) -> GtkSignal.id
-    method notify_ui : callback:(string -> unit) -> GtkSignal.id
   end
 
 type ui_id
